# SzConfigExportResponse

{
"G2_CONFIG": {
"CFG_ATTR": [
{
"ATTR_CLASS": "string",
"ATTR_CODE": "string",
"ATTR_ID": "int32",
"DEFAULT_VALUE": "string",
"FELEM_CODE": "string",
"FELEM_REQ": "string",
"FTYPE_CODE": "string",
"INTERNAL": "string",
"XXX_ADVANCED": "string"
}
],
"CFG_CFBOM": [
{
"CFCALL_ID": "int32",
"EXEC_ORDER": "int32",
"FELEM_ID": "int32",
"FTYPE_ID": "int32"
}
],
"CFG_CFCALL": [
{
"CFCALL_ID": "int32",
"CFUNC_ID": "int32",
"FTYPE_ID": "int32",
"XXX_EXEC_ORDER": "int32"
}
],
"CFG_CFRTN": [
{
"CFRTN_ID": "int32",
"CFUNC_ID": "int32",
"CFUNC_RTNVAL": "string",
"CLOSE_SCORE": "int32",
"EXEC_ORDER": "int32",
"FTYPE_ID": "int32",
"LIKELY_SCORE": "int32",
"PLAUSIBLE_SCORE": "int32",
"SAME_SCORE": "int32",
"UN_LIKELY_SCORE": "int32"
}
],
"CFG_CFUNC": [
{
"ANON_SUPPORT": "string",
"CFUNC_CODE": "string",
"CFUNC_DESC": "string",
"CFUNC_ID": "int32",
"CONNECT_STR": "string",
"XXX_FUNC_LIB": "string",
"XXX_FUNC_VER": "string",
"XXX_JAVA_CLASS_NAME": "string",
"XXX_LANGUAGE": "string"
}
],
"CFG_DFBOM": [
{
"DFCALL_ID": "int32",
"EXEC_ORDER": "int32",
"FELEM_ID": "int32",
"FTYPE_ID": "int32"
}
],
"CFG_DFCALL": [
{
"DFCALL_ID": "int32",
"DFUNC_ID": "int32",
"FTYPE_ID": "int32",
"XXX_EXEC_ORDER": "int32"
}
],
"CFG_DFUNC": [
{
"ANON_SUPPORT": "string",
"CONNECT_STR": "string",
"DFUNC_CODE": "string",
"DFUNC_DESC": "string",
"DFUNC_ID": "int32",
"XXX_FUNC_LIB": "string",
"XXX_FUNC_VER": "string",
"XXX_JAVA_CLASS_NAME": "string",
"XXX_LANGUAGE": "string"
}
],
"CFG_DSRC": [
{
"DSRC_CODE": "string",
"DSRC_DESC": "string",
"DSRC_ID": "int32",
"RETENTION_LEVEL": "string",
"XXX_CONVERSATIONAL": "string",
"XXX_DSRC_RELY": "int32"
}
],
"CFG_DSRC_INTEREST": [
{
"XXX_DSRC_ID": "int32",
"XXX_INTEREST_FLAG": "string",
"XXX_MAX_DEGREE": "int32"
}
],
"CFG_EBOM": [
{
"XXX_ETYPE_ID": "int32",
"XXX_EXEC_ORDER": "int32",
"XXX_FTYPE_ID": "int32",
"XXX_UTYPE_CODE": "string"
}
],
"CFG_EFBOM": [
{
"EFCALL_ID": "int32",
"EXEC_ORDER": "int32",
"FELEM_ID": "int32",
"FELEM_REQ": "string",
"FTYPE_ID": "int32"
}
],
"CFG_EFCALL": [
{
"EFCALL_ID": "int32",
"EFEAT_FTYPE_ID": "int32",
"EFUNC_ID": "int32",
"EXEC_ORDER": "int32",
"FELEM_ID": "int32",
"FTYPE_ID": "int32",
"IS_VIRTUAL": "string"
}
],
"CFG_EFUNC": [
{
"CONNECT_STR": "string",
"EFUNC_CODE": "string",
"EFUNC_DESC": "string",
"EFUNC_ID": "int32",
"XXX_FUNC_LIB": "string",
"XXX_FUNC_VER": "string",
"XXX_JAVA_CLASS_NAME": "string",
"XXX_LANGUAGE": "string"
}
],
"CFG_ERFRAG": [
{
"ERFRAG_CODE": "string",
"ERFRAG_DEPENDS": "string",
"ERFRAG_DESC": "string",
"ERFRAG_ID": "int32",
"ERFRAG_SOURCE": "string"
}
],
"CFG_ERRULE": [
{
"DISQ_ERFRAG_CODE": "string",
"ERRULE_CODE": "string",
"ERRULE_ID": "int32",
"ERRULE_TIER": "int32",
"QUAL_ERFRAG_CODE": "string",
"RELATE": "string",
"RESOLVE": "string",
"RTYPE_ID": "int32",
"XXX_ERRULE_DESC": "string",
"XXX_REF_SCORE": "int32"
}
],
"CFG_FBOM": [
{
"DERIVED": "string",
"DISPLAY_LEVEL": "int32",
"EXEC_ORDER": "int32",
"FELEM_ID": "int32",
"FTYPE_ID": "int32",
"XXX_DISPLAY_DELIM": "string"
}
],
"CFG_FBOVR": [
{
"FTYPE_EXCL": "string",
"FTYPE_FREQ": "string",
"FTYPE_ID": "int32",
"FTYPE_STAB": "string",
"UTYPE_CODE": "string",
"XXX_ECLASS_ID": "int32"
}
],
"CFG_FCLASS": [
{
"FCLASS_CODE": "string",
"FCLASS_DESC": "string",
"FCLASS_ID": "int32"
}
],
"CFG_FELEM": [
{
"DATA_TYPE": "string",
"FELEM_CODE": "string",
"FELEM_DESC": "string",
"FELEM_ID": "int32",
"XXX_TOKENIZE": "string"
}
],
"CFG_FTYPE": [
{
"ANONYMIZE": "string",
"DERIVED": "string",
"FCLASS_ID": "int32",
"FTYPE_CODE": "string",
"FTYPE_DESC": "string",
"FTYPE_EXCL": "string",
"FTYPE_FREQ": "string",
"FTYPE_ID": "int32",
"FTYPE_STAB": "string",
"PERSIST_HISTORY": "string",
"RTYPE_ID": "int32",
"SHOW_IN_MATCH_KEY": "string",
"USED_FOR_CAND": "string",
"VERSION": "int32",
"XXX_DERIVATION": "string"
}
],
"CFG_GENERIC_THRESHOLD": [
{
"BEHAVIOR": "string",
"CANDIDATE_CAP": "int32",
"FTYPE_ID": "int32",
"GPLAN_ID": "int32",
"SCORING_CAP": "int32",
"SEND_TO_REDO": "string"
}
],
"CFG_GPLAN": [
{
"GPLAN_CODE": "string",
"GPLAN_DESC": "string",
"GPLAN_ID": "int32"
}
],
"CFG_RCLASS": [
{
"IS_DISCLOSED": "string",
"RCLASS_CODE": "string",
"RCLASS_DESC": "string",
"RCLASS_ID": "int32"
}
],
"CFG_RTYPE": [
{
"BREAK_RES": "string",
"RCLASS_ID": "int32",
"RTYPE_CODE": "string",
"RTYPE_DESC": "string",
"RTYPE_ID": "int32",
"XXX_REL_STRENGTH": "int32"
}
],
"CFG_SFCALL": [
{
"EXEC_ORDER": "int32",
"FELEM_ID": "int32",
"FTYPE_ID": "int32",
"SFCALL_ID": "int32",
"SFUNC_ID": "int32"
}
],
"CFG_SFUNC": [
{
"CONNECT_STR": "string",
"SFUNC_CODE": "string",
"SFUNC_DESC": "string",
"SFUNC_ID": "int32",
"XXX_FUNC_LIB": "string",
"XXX_FUNC_VER": "string",
"XXX_JAVA_CLASS_NAME": "string",
"XXX_LANGUAGE": "string"
}
],
"CONFIG_BASE_VERSION": {
"BUILD_DATE": "string",
"BUILD_NUMBER": "string",
"BUILD_VERSION": "string",
"COMPATIBILITY_VERSION": {
"CONFIG_VERSION": "string"
},
"VERSION": "string",
"XXX_PRODUCT_NAME": "string"
},
"SETTINGS": {
"METAPHONE_VERSION": "int32"
},
"SYS_OOM": [
{
"FTYPE_ID": "int32",
"NEXT_THRESH": "int32",
"OOM_LEVEL": "string",
"OOM_TYPE": "string",
"THRESH1_CNT": "int32",
"THRESH1_OOM": "int32",
"XXX_FELEM_ID": "int32",
"XXX_LENS_ID": "int32",
"XXX_LIB_FEAT_ID": "int32",
"XXX_LIB_FELEM_ID": "int32"
}
],
"XXX_CFG_ECLASS": [
{
"XXX_ECLASS_CODE": "string",
"XXX_ECLASS_DESC": "string",
"XXX_ECLASS_ID": "int32",
"XXX_RESOLVE": "string"
}
],
"XXX_CFG_ETYPE": [
{
"XXX_ECLASS_ID": "int32",
"XXX_ETYPE_CODE": "string",
"XXX_ETYPE_DESC": "string",
"XXX_ETYPE_ID": "int32"
}
],
"XXX_CFG_LENS": [
{
"XXX_LENS_CODE": "string",
"XXX_LENS_DESC": "string",
"XXX_LENS_ID": "int32"
}
],
"XXX_CFG_LENSRL": [
[
{
"FIXME_KEY": "string"
}
]
]
}
}